@@ -64,8 +64,6 @@ class RmConnectWindow(QtWidgets.QMainWindow):
     @QtCore.pyqtSlot()
     def connect(self) -> None:
         """Connects to a reMarkable device via SSH and lists documents"""
-        self.documents.setRowCount(0)
-        self.documents.clear()
         self.pb_reboot.setEnabled(False)
 
         try:
@@ -80,8 +78,12 @@ class RmConnectWindow(QtWidgets.QMainWindow):
 
         self.rm_ftp = qrm_common.sftp_connection(rm_ssh)
         self.pb_reboot.setEnabled(True)
+        self.populate()
 
-        content = dict(qrm_common.list_docs(self.rm_ftp))
+    def populate(self) -> None:
+        self.documents.setRowCount(0)
+        self.documents.clear()
+        content = dict(sorted(qrm_common.list_docs(self.rm_ftp), key=lambda e: e[1]["visibleName"]))
         for uid, metadata in content.items():
             if metadata["type"] == "DocumentType":
                 parent_str = (
@@ -97,7 +99,7 @@ class RmConnectWindow(QtWidgets.QMainWindow):
 
     def event(self, event: QtCore.QEvent) -> bool:
         if event.type() == QtCore.QEvent.DragEnter:
-            if any(
+            if self.rm_ftp and any(
                 Path(u.url()).suffix.lower() in {".pdf", ".epub"} for u in event.mimeData().urls()
             ):
                 event.accept()
@@ -105,9 +107,12 @@ class RmConnectWindow(QtWidgets.QMainWindow):
             urls = [
                 path
                 for u in event.mimeData().urls()
-                if (path := Path(u.url())).suffix.lower() in {".pdf", ".epub"}
+                if (path := Path(u.url().split(":", 1)[-1])).suffix.lower() in {".pdf", ".epub"}
             ]
             print(urls)
+            for url in urls:
+                qrm_common.upload_file(self.rm_ftp, url)
+            self.populate()
 
         elif not event.type() in {
             QtCore.QEvent.UpdateRequest,
